﻿using API_SequentMicrosystems.Models;
using API_SequentMicrosystems.Services;
using Microsoft.AspNetCore.Mvc;

// For more information on enabling Web API for empty projects, visit https://go.microsoft.com/fwlink/?LinkID=397860

namespace API_SequentMicrosystems.Controllers
{
    [Tags("Internal Saving Points (Recommended use only \"Actual\" endpoint for read all data at once. Saving points is not recomended)")]
    [Route("api/Points")]
    [ApiController]
    public class PointsController : ControllerBase
    {
        private PointsService _PointsService;

        public PointsController(PointsService _PS)
        {
            _PointsService = _PS;
        }

        // GET: api/<PointsController>
        /// <summary>
        /// Get all saved points
        /// </summary>
        /// <returns></returns>
        [HttpGet]
        public List<PointsModel> Get()
        {
            return _PointsService.GetPoints().Take(1000).ToList(); ;
        }

        // GET api/<PointsController>/5/5
        /// <summary>
        /// Read points from and to specified points positions
        /// </summary>
        /// <param name="limit">limit of returned points (Maximum 1000)</param>
        /// <param name="start">id of start element</param>
        /// <returns></returns>
        [HttpGet("{start}/{limit}")]
        public List<PointsModel> Get(int limit, int start)
        {
            if (limit > 1000)
                limit = 1000;

            return _PointsService.GetPoints(start, limit);
        }

        // POST api/<PointsController>/5
        /// <summary>
        /// Read points from and to specified points positions
        /// </summary>
        /// <param name="limit">limit of returned points (Maximum 1000)</param>
        /// <param name="pm">start element</param>
        /// <returns></returns>
        [HttpPost("{limit}")]
        public List<PointsModel> Post(int limit, [FromBody] PointsModel pm)
        {
            if (limit > 1000)
                limit = 1000;

            return _PointsService.GetPoints(limit, pm);
        }

        //GET api/Points/Actual
        /// <summary>
        /// Get Actual Point
        /// </summary>
        /// <returns></returns>
        [HttpGet("Actual")]
        public PointsModel GetActual()
        {
            return _PointsService.GetPoint();
        }

        // GET api/<PointsController>/5
        /// <summary>
        /// Read points from first to specified number
        /// </summary>
        /// <returns></returns>
        [HttpGet("Count")]
        public int GetCount()
        {
            return _PointsService.GetPoints().Count;
        }

        //DELETE api/points
        /// <summary>
        /// Delete saved points
        /// </summary>
        [HttpDelete]
        public void Delete()
        {
            _PointsService.DeletePoints();
        }

        //DELETE api/points
        /// <summary>
        /// Delete Specified saved point
        /// </summary>
        /// <param name="id">Point ID</param>
        [HttpDelete("{id}")]
        public void Delete(int id)
        {
            _PointsService.DeletePoint(id);
        }

        //GET api/points/save
        /// <summary>
        /// Save new point
        /// </summary>
        [HttpGet("save")]
        public void GetSave()
        {
            _PointsService.SavePoint();
        }

        //GET api/points/save/300
        /// <summary>
        /// Start timer to automatic saving points in specified interval
        /// </summary>
        /// <param name="msec"></param>
        [HttpGet("AutoSave/{msec}")]
        public void GetSaveSec(int msec)
        {
            _PointsService.AutoSaveStart(msec);
        }

        //GET api/points/save
        /// <summary>
        /// Stop timer for automatic save points
        /// </summary>
        [HttpDelete("AutoSave")]
        public void DeleteSaveSec()
        {
            _PointsService.AutoSaveStop();
        }




    }
}
